@@ -2,32 +2,27 @@
 
 from __future__ import absolute_import
 
-import logging
-from datetime import datetime, timedelta
 import json
-from functools import wraps
+import logging
 import re
 import string
+from datetime import datetime, timedelta
+from functools import wraps
 
 import jwt
-from six.moves.http_client import UNAUTHORIZED
-
+import marshmallow as ma
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives.serialization import load_pem_public_key
 from flask import current_app, request, _request_ctx_stack, g, url_for, redirect, make_response
 from flask.views import MethodView
 from flask_smorest import Blueprint, abort
-
-import marshmallow as ma
-
+from six.moves import http_client
 from werkzeug.local import LocalProxy
 from werkzeug.security import gen_salt
 
-from drift.utils import get_tier_name
-from drift.core.extensions.urlregistry import Endpoints
 from drift.core.extensions.tenancy import current_tenant_name, split_host
-
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives.serialization import load_pem_public_key
-
+from drift.core.extensions.urlregistry import Endpoints
+from drift.utils import get_tier_name
 
 JWT_VERIFY_CLAIMS = ['signature', 'exp', 'iat']
 JWT_REQUIRED_CLAIMS = ['exp', 'iat', 'jti']
@@ -45,7 +40,7 @@ TRUSTED_ISSUERS = set(['drift-base'])
 WHITELIST_ENDPOINTS = [
     r"^api-docs\.",  # the marshmalloc documentation endpoint
     r"^static$",  # the marshmalloc documentation endpoint
-    ]
+]
 
 SESSION_COOKIE_NAME = 'drift-session'
 
@@ -166,7 +161,7 @@ def abort_unauthorized(description):
     """
     Raise an Unauthorized exception.
     """
-    abort(UNAUTHORIZED, description=description)
+    abort(http_client.UNAUTHORIZED, description=description)
 
 
 def register_auth_provider(app, provider, handler):
@@ -180,6 +175,7 @@ def requires_roles(_roles):
         endpoint decorator to lock down an endpoint
         on a set of roles (comma delimitered)
     """
+
     def wrapper(fn):
         @wraps(fn)
         def decorator(*args, **kwargs):
@@ -202,7 +198,9 @@ def requires_roles(_roles):
                 abort_unauthorized("You do not have access to this resource. "
                                    "It requires role '%s'" % _roles)
             return fn(*args, **kwargs)
+
         return decorator
+
     return wrapper
 
 
@@ -299,6 +297,7 @@ def _authenticate(auth_info, conf):
 class AuthRequestSchema(ma.Schema):
     class Meta:
         strict = True
+
     provider = ma.fields.Str(description="Provider name")
     provider_details = ma.fields.Dict(description="Provider specific details")
     username = ma.fields.Str(description="Legacy username")
@@ -309,6 +308,7 @@ class AuthRequestSchema(ma.Schema):
 class AuthSchema(ma.Schema):
     class Meta:
         strict = True
+
     token = ma.fields.String(description="Token")
     jti = ma.fields.String(description="Token id")
 
@@ -319,7 +319,7 @@ class AuthApi(MethodView):
     no_jwt_check = ['GET', 'POST']
 
     @bp.arguments(AuthRequestSchema)
-    @bp.response(AuthSchema)
+    @bp.response(http_client.OK, AuthSchema)
     def post(self, auth_info):
         auth_info = _authenticate(auth_info, g.conf)
         return {
@@ -381,9 +381,9 @@ def authenticate_with_provider(auth_info):
         handler = current_app.jwt_auth_providers.get("default")
     if not handler:
         abort_unauthorized(
-                "Bad Request. Unknown provider '{}'. Only 'jwt' and 'jti' are "
-                "supported".format(auth_info['provider'])
-            )
+            "Bad Request. Unknown provider '{}'. Only 'jwt' and 'jti' are "
+            "supported".format(auth_info['provider'])
+        )
     return handler(auth_info)
 
 
@@ -556,7 +556,7 @@ def verify_token(token, auth_type, conf):
     tier_name = get_tier_name()
     if tier != tier_name:
         abort_unauthorized("Invalid JWT. Token is for tier '%s' but this"
-            " is tier '%s'" % (tier, tier_name))
+                           " is tier '%s'" % (tier, tier_name))
 
     # Verify tenant
     if 'tenant' not in payload:
@@ -569,7 +569,7 @@ def verify_token(token, auth_type, conf):
         this_tenant = current_tenant_name
     if tenant != this_tenant:
         abort_unauthorized("Invalid JWT. Token is for tenant '%s' but this"
-            " is tenant '%s'" % (tenant, this_tenant))
+                           " is tenant '%s'" % (tenant, this_tenant))
 
     return payload
 
@@ -604,7 +604,7 @@ def cache_token(payload, expire=None):
 
     # Add fudge to 'expire' so the token will live at least a little bit longer in the
     # Redis cache than the actual expiration date.
-    expire += 60*10  # Ten minutes
+    expire += 60 * 10  # Ten minutes
 
     try:
         jti = payload['jti']
@@ -625,7 +625,6 @@ def get_cached_token(jti):
     return payload
 
 
-
 # https://stackoverflow.com/questions/561486/how-to-convert-an-integer-to-the-shortest-url-safe-string-in-python
 ALPHABET = string.ascii_uppercase + string.ascii_lowercase + string.digits + '-_'
 ALPHABET_REVERSE = dict((c, i) for (i, c) in enumerate(ALPHABET))
@@ -655,8 +654,10 @@ def num_decode(s):
 
 class JwkSchema(ma.Schema):
     """JSON Web Key"""
+
     class Meta:
         strict = True
+
     kty = ma.fields.String(description="Key Type")
     use = ma.fields.String(description="Public Key Use")
     alg = ma.fields.String(description="Algorithm")
@@ -667,6 +668,7 @@ class JwkSchema(ma.Schema):
 class JwksSchema(ma.Schema):
     class Meta:
         strict = True
+
     keys = ma.fields.List(ma.fields.Nested(JwkSchema))
 
 
@@ -679,7 +681,7 @@ class JWKSApi(MethodView):
     no_auth_header_check = True
     no_jwt_check = ['GET']
 
-    @bp.response(JwksSchema)
+    @bp.response(http_client.OK, JwksSchema)
     def get(self):
         from driftconfig.util import get_default_drift_config
         ts = get_default_drift_config()
